@@ -127,7 +127,8 @@ c
 
       if(UseTbl .and. z .lt. Htop) then
          leng = ct2lTA(z,  t)
-      elseif( abs(cosz) .gt. nearv ) then
+      elseif( abs(cosz) .gt. nearv .or. 
+     *  ( z .lt. 15.d3  .and. t .lt. 350.0d0 ) ) then
          t1 = cvh2thick(z)
          t2 = t1 + cosz* t
          if(t2 .le. 0.) then
@@ -138,11 +139,14 @@ c
          zp = cthick2h(t2)
 c         leng = clenbetween2h(z+Eradius, zp+Eradius, cosz)
          call clenbetw2h(z+Eradius, zp+Eradius, cosz, leng, icon)
+
+         
          if(icon .ne. 0) then
 c            cannot reach to zp. This may happen if z is very large
             iterate = 1
          else
-            if(abs(cosz) .lt. nearv2) then
+c            if(abs(cosz) .lt. nearv2) then
+            if( t .gt. 350.d0 ) then
 c              correction by using  cos at middle of leng
                cosp = cnewcos(z+Eradius, cosz, leng/2)
                t2 = t1 + cosp * t
@@ -181,7 +185,7 @@ c               at very high altitude,  rhop = 0
 
       
          if(rhop .ne. 0.) then
-            do i=1,6
+            do i=1,3
 c               get height and cos at s/2 ahead.
                cosp = cnewcos(Eradius+z, cosz, s/2)
                zp = cnewh(Eradius+z, cosz, s/2) - Eradius
@@ -210,3 +214,4 @@ c  &&&&&&&&&
          leng =t / rho
       endif
       end
+
