@@ -606,7 +606,7 @@ c                     see if this is > K.E
                Eloss = Ek
                dist = Eloss/dedt
             endif
-            Eloss = Eloss*10.       !  GeV/(g/cm2)
+            Eloss = Eloss*aTrack.wgt       !  GeV/(g/cm2)
             SumEloss(ldep)=SumEloss(ldep) + Eloss
          endif
       endif
