@@ -74,50 +74,16 @@ c      root(s)  GeV
 #include "Zevhnp.h"
 
        real*8 roots, avn
-c       real*8 lambda/0.3/, no/0.34/, qcdErg/73./
 c       real*8 lambda/0.3/, no/0.6135/, qcdErg/1000./  ! up to 1000 GeV.
 c                              | this is wrong (total  multiplicity)
-c       real*8 lambda/0.3/, no/0.315/, qcdErg/1000./  ! up to 1000 GeV.
-        real*8 lambda/0.3/, no/0.36/, qcdErg/1500./  ! up to 1500 GeV.
+        real*8 lambda/0.3/, no/0.34/, qcdErg/1000./  
 c                           
-c                we use UA5 data.
-
+c               e UA5 data.
 c                   original
 c       avn= 7.2* roots**(2*0.127) -7.   including  leading.
 c
-c       if(roots .lt. 32.) then
-       if(roots .lt. 50.) then
-c          avn= 7.2* roots**(2*0.1) - 7
-c          avn= 0.9 * roots**0.65
-c           avn= 1.3 * roots**0.55
-c           avn= 1.1 * roots**0.6
-           avn= 1.25 * roots**0.55
-       elseif(roots .gt. qcdErg .and. MulLow .eq. 1) then
-c             2.5 is cosmos adjusting factor. (2 is leading)
-c////////////
          avn = no* exp(sqrt(23./18. * log( (roots/lambda))*2))
-c    *          -2.5
-c          avn =  1.25 * roots**0.55
-c//////////////
-       else
-c           all graphs have been draw with this 
-c           one can fit ua5 non-single diffrective data, but 
-c           it is not the data to be fitted. used before uv.3.00 
-c           mistakenly.
-c          avn= 7.2* roots**(2*0.127) - 8.0  ! 2.5 for adj. 2 is leading
-c               too strong power.  very good at root s = 53 
-c          avn= 6.9* roots**(2*0.127) - 8.0  ! 2.5 for adj. 2 is leadingc 
-c               finally adopeted
-c/////////
-ccc///           avn= 7.1* roots**(2*0.124) - 8.0  ! 2.5 for adj. 2 is leading
-          avn =  1.25 * roots**0.55
-c/////////
-c           avn= 6.8 * roots**(2*0.124) - 8.0  ! 2.5 for adj. 2 is leading
-       endif
-c           at roots > 50 GeV, we may try a QCD prediction like
-c           avn = N * exp(sqrt(23./18. * log( (roots/lamda))*2 ))
-c         with N = 0.34 and lamda=0.3 (GeV).  this give 
-c         slightly smaller number than the above one at Elab > 400 TeV
+     *          -2
 c
 c
       end
