@@ -23,9 +23,13 @@ c
            if( ke  .lt. KEminCas2) then
               call rndsw(jold, 2)
            endif
-           if( ke .lt.  KEminCas) then
+           if(a.p.charge .eq. 1) then
+              if(a.p.fm.p(4) .lt. KEminCas) then
+                 icon = 1
+              endif
+           elseif( ke  .lt.  KEminCas ) then 
               icon = 1
-           endif   
+           endif
         elseif(a.p.code .eq. knuc) then
            if( a.p.subcode .eq. antip) then
 c               can annihilate
