@@ -44,6 +44,7 @@ c            mul. scatt and lpm
          if(Reverse .eq. 0) then
 ccc            if(TrackBefMove.pos.height .lt. AlmostVacH) then
             call cmaxCasLen(TrackBefMove, ztrunc)
+
             if(TrackBefMove.p.fm.p(4) .gt. LpmBremEmin
      *         .and. LpmEffect) then
                ztrunc =
@@ -162,17 +163,12 @@ c
 
 
       ek = aTrack.p.fm.p(4) - aTrack.p.mass
-      if(TimeStructure) then
-         if(ek  .gt. 1.) then
-            ttrunc=2.
-         else
-            ttrunc=1.66*ek + 0.333
-            ttrunc=min( max(Truncc*ek, Truncn), Truncx)
-         endif
+      if(ek .gt. 1.d-3) then
+         ttrunc=min( ek*5.0d0, 1.d0)
       else
-         ttrunc=min( max(Truncc*ek, Truncn), Truncx)
+         ttrunc = max(1.d-3, ek*2.d0)
       endif
-      kgpm2 = max(ttrunc, Truncn) * X0 ! max.  to avoid very small thick.
+      kgpm2= ttrunc*X0
       end
 c    *************************************
       subroutine cmagDefR(aTrack, mag, r)
